# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project *loosely* adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
The main difference is that the MAJOR.MINOR.PATCH system doesn't change the MAJOR indicator, as most version changes are NOT backwards compatible and the MINOR indicator will increase regardless of if that version can be played in an earlier update.
However, if the version update is a bug fix/patch/update that does NOT change the resourcepack or datapack format, then the PATCH indicator will be updated accordingly.
TL;DR: This follows Mojang's update structure for Minecraft updates.

Anything noted as (Undocumented) is because I didn't write down the change at that time and can't remember what was added/removed/edited. Sorry.

## [Unreleased]
- Foods to be added:
  - Marshmallows
  - S'mores
  - Various Burgers
  - Bagels
  - Curry
  - French Toast
  - Garlic Bread
  - Chocolate Milk
  - Mashed Potatoes
  - Cactus Fruit
- Features to be added:
  - Gourmand's Digest functionality

## [1.1.0] - 2024-6-14

### Added
#### Foods
- Added Ramen (Thank you Hans and Timothy!)
- Added Shepard's Pie
- Added Grilled Cheese Sandwiches (Thanks Jack!)
- Added Honey 'Garlic' Chicken
- Added Hot Dogs
- Added Veggie Dogs
- Added Perogies
- Added Tea
- Added Coffee
- Added Roasted Carrots
  - Carrots can only be roasted using a Smoker or a Campfire (cooking it in a furnace would burn it silly)
- Added Snow Cones
  - Snow Cones are foods that come in a variety of colors, but all restore the same amount of food and saturation. The colors available are: Red, Black, Blue, Green, Light Blue, Lime, Orange, Pink, Purple, White, and Yellow. Making these were a pain in the a## and it isn't even all the colors in the game
  - Only the RED Snow Cone is required for the "The Gourmand" advancement, so you don't need to eat all 11. You're welcome.
  - Additionally, only the Red Snow Cone is tracked for the "Extra Dietary Options" advancement, so crafting any other color of Snow Cone won't activate it
- Added Lasagna
- Added Chocolate Cake (slices)
- Added White, Milk, and Dark Chocolate Bars (Thanks G4act1co!)
- Added Churros (Thanks again, G4act1co!)
  - Churros behave like Kabobs, where eating one creates a new, smaller Churro with slightly less nutrition and saturation values
- Added Quesadillas
- Added Veggie Quesadillas
- Added Croissants
- Added Brownies
- Added Mac & Cheese
- Added Popcorn (A highly requested addition, thank you everyone!)
- Added Chicken Noodle Soup (Thanks StarWarsBlaster!)
- Added Chicken Parmesan (Thanks Eric!)
  - I won't lie, the Chicken Parmesan texture is... iffy. It will likely be changed in a later update
- Added Baguettes (Thanks Makenna!)
#### Items
- Added Coffee Beans
  - Coffee Beans can be sourced from breaking Jungle Leaves or Short Grass/Ferns in Jungle Biomes, and are required to make Coffee
#### Advancements
The following advancements have been added:
- "Iron Belly" for eating Rotten Flesh while at 0 Hunger Points
- "Drinkoholic" for consuming all available Drinks
- "(Most) Colors of the Rainbow" for eating every available color of Snow Cone
- "Locally Sourced" for finding Coffee Beans in Jungle Trees or in Jungle Grass/Ferns
- "Soy To The Rescue!" for crafting Tofu
- "Nature's Acidic Apples" for obtaining Tomatoes from either a Village or the Tomato crop
- "The Perfect Assembly" for crafting an MCT Sandwich
- "Lil' Sundial" for holding a Clock in either the Mainhand or Offhand to track the time
- "A Balanced Breakfast" for consuming a Bowl of Cereal, any bottled drink, and either a Banana, any Fried Egg, Apple, or Croissant between 6 AM and 11 AM (in daytime)
- "Watching The Show" for eating Popcorn inside a house while it rains or thunders outside
- "Totally Grainular!" for eating a Baguette, Croissant, Pretzel, Plain Donut, and Bread
- "Cookie Enthusiast" for eating a Honey Cookie, a Cocoa Cookie, both kinds of Berry Cookie, and a regular Cookie
#### Recipes
- Added a recipe for turning Tomatoes into Tomato Seeds
  - The recipe for creating Red Dye from Tomatoes has also been edited
#### Tags
- Added Melons and Pumpkins to the ```mineable``` tag for hoes, so they can now be mined faster with hoes
  - This gives an alternative way of mining melons quickly, as trying to do so with an axe will just break it into slices. Pumpkins don't share this trait--their "harder" exterior prevents them from being broken into slices by axe. Players still must do so at a Stonecutter like before
#### Misc
- Implemented a Changelog format based on keepachangelog.com. It's been edited slightly to better fit these updates, but it should vastly improve readability
  - Previous updates have also had their changelogs updated to fit the same format--did you notice?
- Added a changelog file to the download of the pack. So, you can easily see all the current changes as well as the past ones from any future version you install
- **Changed the namespace of the pack to ```rmf``` for "Reg's More Foods" (from ```morefoods```)**. Any commands that required typing in that namespace will now require ```rmf``` instead (example: ```rmf:a_balanced_breakfast``` advancement)
  - Previous references of the old namespace in changelogs will not be corrected, only future references will be
  - This could cause a lot of issues, so if you find any bugs please let me know!
- Created modded versions of the pack, so you can play it on Forge/Fabric/Quilt worlds or in modpacks now
  - A Forge version will be created when Forge actually updates to 1.21 (please)
- Zombies and Husks now drop Zombie Jerky and Roasted Carrots if killed with fire
  - This behaves the same way as how killing them with fire makes them dropped Baked Potatoes instead of regular Potatoes
- Various foods can now be found in loot chests
  - For example, Cheese can occasionally be found in Plains Villages (as well as Desert Temples), Red Snow Cones (specifically) can be found in Snowy Villages, and Bananas can be found in Savanna Villages
- Added a new system for tracking the daytime of the game
  - The time reads in 12 Hour format on the Actionbar (above the player hotbar), updating every "30 minutes" in game whenever a player holds a Clock in their Mainhand or Offhand
  - This was added to assist with the "A Balanced Breakfast" advancement, so players could tell exactly what time it was in the world
  - This functionality is *enabled* by default but can be disabled in the config settings
- **Added a new Food Classification System**
  - Foods are now classed as one of the following: *Entrées*, *Starters*, *Appetizers*, *Sides* and *Drinks*
  - Classifications aren't used in-game, but are referenced in Wiki pages as well as the Gourmand's Digest to help players know what to expect from any particular food they may not have eaten yet
### Changed
- Changed the ```pack.png``` of the packs
- Changed the system that Kabobs use to make them more seamless
  - They now use 24w19a's new ```food``` component system
- Updated Kabobs to be stackable (each level now stacks up to 3)
- Changed the filename for the changelog that you're reading right now to ```CHANGELOG.md``` (from ```changelog.txt```)
- Changed the folder name structure of the data pack to match with 24w21a's update
  - All data pack folder names have been updated to be of "singular" fashion: this means that ```blocks``` and ```functions```, for example, have now become ```block``` and ```function```. The only exception is ```tags```
- Moved several files around and added an ```rmf``` namespace for the resourcepack
- Changed the "A Redditor's Breakfast" advancement name to "A Light Breakfast"
  - The file name of ```redditor_breakfast``` has also been changed to ```a_light_breakfast```
- Edited the description of the "Extreme Dieting" advancement
- Moved the "Desperate Times" and "Extreme Dieting" advancements to be under "Iron Belly"
- Renamed the bowls of Ice Cream and Chocolate Ice Cream to just "Ice Cream" and "Chocolate Ice Cream"
- Changed the textures for Ice Cream and Chocolate Ice Cream, as well as their food and saturation values slightly
- Changed the way Ice Cream and Chocolate Ice Cream works as an item, meaning that previous versions of the item will be depreciated and likely have broken textures
  - If you had an older version of the pack in your world with Ice Cream in it, it will likely have a broken texture. Feel free to delete it by throwing it away somewhere. Or don't. I don't control you
- Renamed Yogurt to "Bottle of Yogurt"
- Renamed Apple Juice to "Bottle of Apple Juice"
- Renamed Fruit Punch to "Bottle of Fruit Punch"
- Made Apple Pie and Apple Pie Slices more bearable to look at (updated their textures)
- Updated the texture for Tomato Seeds and Tomatoes
- Updated the texture for the Tomato crop block (it looks like tomatoes are actually growing now!)
- Changed the icon for the "No Room For Seconds" advancement
- Tweaked the food and saturation values for the MCT Sandwich and Fish and Chips
  - At the previous values, Fish and Chips were almost as good as the MCT Sandwich. That was a problem because Fish and Chips are significantly easier to create and much cheaper. They have been edited to provide a little less nutrition and saturation while still being a good early game food item
  - The MCT Sandwich was also tweaked because the recipe, despite requiring either beating the game or challanging an Ocean Monument, was overpowered for its price. It now restores slightly less nutrition and saturation values, but it is still a powerful--if not the best--food item in the pack
- Reduced the amount of Pretzels gained per recipe to 1 (from 3) and changed its food classification to "Starter" (from "Snack")
  - Pretzels are a very easy food to farm given how they only require Wheat, and eating all 3 gained from crafting would yield 15 hunger points (7.5 bars) which is crazy. Rather than reduce the food value, I thought it would be better to reduce the amount of them gained per recipe
- Increased the nutrition and saturation values of Pretzels
  - Since I removed the main gimmick of Pretzels (being that despite being as filling as normal bread, you could make more of them and eat them whenever) I increased their food values to be a *bit* better than regular bread. For 2 extra wheat, you get 6 nutrition and 8 saturation than Bread's 5 nutrition and 6 saturation. However, Pretzels still take 0.2 more seconds to eat than bread
- Slightly reduced the nutrition value of Plain Donuts to 5 (from 6)
  - Due to all the changes made to Pretzels, there become no need to bother making them because Plain Donuts were cheaper to craft and also more filling. So, this was a necessary nerf. Don't worry, though! The recipe still yields 2 Plain Donuts per every 4 Wheat, totalling 10 hunger points per recipe
- Updated the "Edible Gold" advancement to include finding Cheese in chests as well as crafting it
- Updated the "Quite Apeeling" advancement to include finding Bananas in chests as well as from Acacia trees
- Changed the frame of the "(Most) Colors of the Rainbow" and "Drinkoholic" advancements to "task" (from "goal")
- Edited the description of the "(Most) Colors of the Rainbow" advancement
- Renamed Cereal to "Bowl of Cereal"
- Attempted to make Apples more common from Oak trees
- Tweaked the texture of Cheese
- Tweaked the texture of the Bowl of Cereal
- Updated "The Gourmand" and "Extra Dietary Options" advancements
- Tweaked the Apple Juice recipe to be shaped instead of shapeless
- Tweaked the Powder Snow Bucket recipe to be shaped instead of shapeless
- Tweaked the Apple Pie Slice recipe to be shaped instead of shapeless
- Grouped Apple Pies and Apple Pie Slices together in the Recipe Book
### Removed
- Removed the old Kabob use system's files to instead use 24w19a's new ```food``` component system, which allows for directly changing what item a food converts into 

### Depreciated
- Reworked the Bowl of Ice Cream and Bowl of Chocolate Ice Cream into "Ice Cream" and "Chocolate Ice Cream"
  - The old versions of these items will show as broken textures if they already existed in your world. You can throw them out if they bother you
  
### Fixes
- [RMF-4](https://github.com/regfunkid/reg-more-foods/issues/4): Zombie Jerky doesn't apply hunger correctly
- [RMF-5](https://github.com/regfunkid/reg-more-foods/issues/5): Golden Apple Juice obtained from the /give command doesn't stack with crafted Golden Apple Juices
- [RMF-6](https://github.com/regfunkid/reg-more-foods/issues/6): Kabob moves to next available slot when used, instead of replacing mainhand
- [RMF-8](https://github.com/regfunkid/reg-more-foods/issues/8): Poisonous Potatoes from fully grown Potato crops appear as Tofu
- [RMF-9](https://github.com/regfunkid/reg-more-foods/issues/9): Tropical Fish dropped from fish and obtained by fishing appears as Cheese
- [RMF-13](https://github.com/regfunkid/reg-more-foods/issues/13): Eating a Bowl of Cereal doesn't give back the bowl used to craft it

### Bugs
- [RMF-12](https://github.com/regfunkid/reg-more-foods/issues/12): Snow Cones and Churros, for some horrid reason, are unable to stack together if the player is in Creative Mode 
  - This also affects Snow Cones and Churros obtained from the /give system, so they can't be stacked with their crafted varients either
  - This bug wasn't caused be me--it's a bug with Minecraft which i've reported [here](https://bugs.mojang.com/browse/MC-272969)
- [RMF-14](https://github.com/regfunkid/reg-more-foods/issues/14): Crafted Bowls of food don't stack with their variants obtained from the /give system

## [1.0.0] - 2024-05-01

### Added Features
#### Foods
- Added Bananas, which can be found in Acacia Trees
- Added Mangos, which can be found in Mangrove Trees
- Added Cheese Pizza Slices
- Added Veggie Pizza Slices
#### Items
- Added the Gourmand's Digest
  - A cookbook which acts as a mini in-game wiki. Currently has no functionality, will be given some in a later update
  - It can be crafted by cooking a Book & Quill in a Furnace
#### Recipes & Data
- Added a loot table to Cakes, so you can pick one up if no slices have been taken from it
- Added a new recipe for Frosted Pumpkin Pie so players can add frosting to already made Pumpkin Pies as well
#### Advancements
The following advancements have been added:
- "Quite Appeeling" for finding Bananas
- "Juicy Fruit" for finding Mangos
- "Vegan(?) Leather" for cooking Rotten Flesh into Leather in a Blast Furnace
- "Cranking Up The Heat" for smelting a custom recipe in a Blast Furnace, or obtaining a Blast Furnace
- "Hey, That's Ours!" for scraping Honeycomb from a Beehive or Bee Nest, and then eating it
- "Syrup, But From Bees" for obtaining a Honey Bottle
- "Cooking For Dummies" for obtaining the Gourmand's Digest
- "A Redditor's Breakfast" for eating a Cake, whole, without placing it down
- "No Room For Seconds" for being completely full (player saturation level is at 20)
- "Literally Starving" for being completely hungry (the hunger level is at 0)

### Changed
- Renamed "Pizza Slice" to "Meaty Pizza Slice"
- Renamed "Vegan Taco" to "Veggie Taco", and changed its texture
- Renamed "Fish Roll" to "Sea Snack", and changed its recipe as well as its texture and food value
- Edited Melons to drop Melon Slices automatically when broken with an Axe
- Edited the "MCT Sandwich" recipe to require wheat, instead of an outrageous amount of bread
- Edited the "Veggie Taco" recipe to not just require Tofu
- Increased the saturation of Melon Slices to 2.2 Points (from 1.2)
- Moved the "A Caveman's Breakfast" advancement under "Cranking Up The Heat"
- Moved the "A Multipurpose Snack" advancement under "Syrup, But From Bees"
- Renamed the "Conk!" advancement to "A Hairy Apple?"
- Updated the ```root```, "Extra Dietary Options" and "The Gourmand" advancements again (that's gonna be a recurring thing btw)
- Moved ```morefoods:campfire/leather``` to the ```blasting``` category (now ```morefoods:blasting/leather```)
- Changed the "Edible Gold" advancement filepath name to ```edible_gold``` (from ```crafted_cheese```)

### Removed
- Removed Cheese from the ```veg_burrito_ingredients``` tag due to recipe conflicts
- Removed ```morefoods:campfire/fried_egg``` from the ```root``` and "Extra Dietary Options" advancement requirements as there's no actual way to check for it, making it irrelevant

### Config
- Added a Config Menu
- **Added a new Give Command system!**
  - Type ```/give @p knowledge_book[custom_data={item_id:(item_id)}]``` to give any custom food
  - Custom food IDs can be found on the Wiki (after i add them), or using ```/function morefoods:config``` and clicking the "commands" button

### Known Bugs
- Golden Apple Juice from the give command doesn't stack with crafted Golden Apple Juices
  - I will try to fix this, but I honestly don't know what causes it and it's not exactly a huge issue. Maybe a future Minecraft update will fix this for me, who knows.

## [1.2.0-beta] - 2024-04-18

### Added
#### Recipes & Data
- Added a new Advancement category for the pack, as well as a background image
- Added a new recipe for Melon Seeds, so players don't need to cut a Melon in a Stonecutter first just to get seeds from the slices
#### Advancements
The following advancements have been added:
- "Edible Gold" for crafting Cheese
- "Desperate Times" for eating Zombie Jerky

### Changed
- Edited the Melon recipe to only require 4 Melon Slices instead of 9, so players making Melon Slices from them wouldn't be losing 5 slices per recipe
- Updated the ```root```, "Extra Dietary Options", and "The Gourmand" advancements (to account for the new food and recipe added)
- Added a ```root``` directory meant for storing recipe advancements (unachievable in normal gameplay)
- Moved the recipe advancements to ```morefoods:recipes/root``` (from ```minecraft:recipes/root```)
- Moved "The Gourmand" advancement to be under the ```root``` to make the advancement tree neater
- Renamed the following advancement filepaths:
  - ```extreme_dieting``` (from ```ate_monster_mash```)
  - ```caveman_breakfast``` (from ```ate_sniffer_egg```)
  - ```dragon_breakfast``` (from ```ate_dragon_egg```)

### Fixes
- Fixed a bug where Zombie Jerky didn't give the Hunger effect properly
- Fixed a bug where, apparently, I shipped this version WITHOUT a data folder! So the whole pack didn't exist! Whoopsies! :333

## [1.0.0-beta] - 2024-04-16

### Added
#### Foods
- Added a new "Stuffed Potato" food and recipe
#### Recipes & Data
- 2 new recipes were added to the Stonecutter (Undocumented)
#### Advancements
The following advancements have been added:
- "Jumbo Juice" for drinking Golden Apple Juice 
- "JUMBO Jumbo Juice" for drinking Enchanted Golden Apple Juice (Hidden Advancement) 
- "A Multipurpose Snack" for eating a Honeyball 
- "Accidental Alchemy" for crafting a Slime Block with Honeyballs

### Changed
- "Pumpkin Slice" recipe was moved to the Stonecutter (Undocumented)
- Melons no longer drop Melon Slices; Instead, they now drop as full blocks which must be cut in a Stonecutter for slices
- "The Gourmand" & "Extra Dietary Options" Advancements have been updated to include the new recipes added

### Removed
- "10,000 Calorie Meal" Advancement has been removed

### Fixes
- Several bug fixes (Undocumented)

## [1.0.0-alpha] - 2024-04-15

This is the first version of the project. No other information was written earlier, so I have nothing to write here...